local _,rematch = ...
local L = rematch.localization
local C = rematch.constants
rematch.badges = {}

local badges = {
    marker1 = {"Interface\\AddOns\\Rematch\\textures\\badges-borderless",0,0.125,0.25,0.375}, -- star
    marker2 = {"Interface\\AddOns\\Rematch\\textures\\badges-borderless",0.125,0.25,0.25,0.375}, -- circle
    marker3 = {"Interface\\AddOns\\Rematch\\textures\\badges-borderless",0.25,0.375,0.25,0.375}, -- diamond
    marker4 = {"Interface\\AddOns\\Rematch\\textures\\badges-borderless",0.375,0.5,0.25,0.375}, -- triangle
    marker5 = {"Interface\\AddOns\\Rematch\\textures\\badges-borderless",0.5,0.625,0.25,0.375}, -- moon
    marker6 = {"Interface\\AddOns\\Rematch\\textures\\badges-borderless",0.625,0.75,0.25,0.375}, -- square
    marker7 = {"Interface\\AddOns\\Rematch\\textures\\badges-borderless",0.75,0.875,0.25,0.375}, -- cross
    marker8 = {"Interface\\AddOns\\Rematch\\textures\\badges-borderless",0.875,1,0.25,0.375}, -- skull
    leveling = {"Interface\\AddOns\\Rematch\\textures\\badges-borderless",0.375,0.5,0.125,0.25}, -- leveling blue arrow
    team = {"Interface\\AddOns\\Rematch\\textures\\badges-borderless",0.5,0.625,0.125,0.25}, -- team green paw
    preferences ={"Interface\\AddOns\\Rematch\\textures\\badges-borderless",0.75,0.875,0.125,0.25}, -- preferences blue gear
    targets = {"Interface\\AddOns\\Rematch\\textures\\badges-borderless",0.375,0.5,0.375,0.5}, -- target
}

local badgeArrays = {} -- indexed by the parentArray, the number of badges used

-- clears the badges from the given array of textures
function rematch.badges:ClearBadges(array)
    badgeArrays[array] = 0
    for _,badge in ipairs(array) do
        badge:Hide()
    end
end

-- adds a named badge ("leveling", "marker3", etc.) to the given array of textures (parentArray of badges)
-- xdir should be -1 for badges that go right to left, 1 otherwise
function rematch.badges:AddBadge(array,badge,anchorPoint,relativeTo,relativePoint,xoff,yoff,xdir)
    assert(badges[badge],"Badge "..(badge or "nil").." doesn't exist")
    if not badgeArrays[array] then
        badgeArrays[array] = 1 -- not seen this one before, start at 1
    else
        badgeArrays[array] = badgeArrays[array] + 1 -- otherwise increment to next one
    end
    local index = badgeArrays[array]
    if not array[index] then
        array[index] = array[1]:GetParent():CreateTexture(nil,"ARTWORK")
        array[index]:SetSize(C.BADGE_SIZE,C.BADGE_SIZE)
    end
    array[index]:ClearAllPoints()
    array[index]:SetPoint(anchorPoint,relativeTo,relativePoint,(C.BADGE_SIZE+1)*(index-1)*xdir+xoff,yoff)
    array[index]:SetTexture(badges[badge][1])
    array[index]:SetTexCoord(badges[badge][2],badges[badge][3],badges[badge][4],badges[badge][5])
    array[index]:Show()
    return array[index]
end
